@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gnome.h>
 #include <string.h>
 #include "xml-compat.h"
@@ -41,6 +40,7 @@
 #include "part-label.h"
 #include "sim-settings.h"
 #include "textbox.h"
+#include "errors.h"
 
 typedef enum {
 	PARSE_START,
@@ -241,7 +241,7 @@ create_part (ParseState *state)
 }
 
 int
-schematic_parse_xml_file (Schematic *sm, const char *filename)
+schematic_parse_xml_file (Schematic *sm, const char *filename, GError **error)
 {
 	ParseState state;
 	int retval  = 0;
@@ -254,11 +254,24 @@ schematic_parse_xml_file (Schematic *sm, const char *filename)
 
 	if (oreganoXmlSAXParseFile (&oreganoSAXParser, &state, filename) < 0) {
 		g_warning ("Document not well formed!");
+		if (error != NULL) {
+			g_set_error (error,
+				OREGANO_ERROR,
+				OREGANO_SCHEMATIC_BAD_FILE_FORMAT,
+				_("Bad file format."));
+		}
 		retval = -1;
 	}
 
-	if (state.state == PARSE_ERROR)
+	if (state.state == PARSE_ERROR) {
+		if (error != NULL) {
+			g_set_error (error,
+				OREGANO_ERROR,
+				OREGANO_SCHEMATIC_BAD_FILE_FORMAT,
+				_("Unknown parser error."));
+		}
 		retval = -2;
+	}
 
 	schematic_set_author (sm, state.author);
 	schematic_set_title (sm, state.title);
@@ -291,7 +304,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 {
 	switch (state->state) {
 	case PARSE_START:
-		if (strcmp (name, "ogo:schematic")) {
+		if (xmlStrcmp (name, "ogo:schematic")) {
 			g_warning ("Expecting 'ogo:schematic'.  Got '%s'", name);
 			state->state = PARSE_ERROR;
 		} else
@@ -299,25 +312,25 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_SCHEMATIC:
-		if (!strcmp (name, "ogo:author")) {
+		if (!xmlStrcmp (name, "ogo:author")) {
 			state->state = PARSE_AUTHOR;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:title")) {
+		} else if (!xmlStrcmp (name, "ogo:title")) {
 			state->state = PARSE_TITLE;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:comments")) {
+		} else if (!xmlStrcmp (name, "ogo:comments")) {
 			state->state = PARSE_COMMENTS;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:zoom")) {
+		} else if (!xmlStrcmp (name, "ogo:zoom")) {
 			state->state = PARSE_ZOOM;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:simulation-settings")) {
+		} else if (!xmlStrcmp (name, "ogo:simulation-settings")) {
 			state->state = PARSE_SIMULATION_SETTINGS;
-		} else if (!strcmp (name, "ogo:parts")) {
+		} else if (!xmlStrcmp (name, "ogo:parts")) {
 			state->state = PARSE_PARTS;
-		} else if (!strcmp (name, "ogo:wires")) {
+		} else if (!xmlStrcmp (name, "ogo:wires")) {
 			state->state = PARSE_WIRES;
-		} else if (!strcmp (name, "ogo:textboxes")) {
+		} else if (!xmlStrcmp (name, "ogo:textboxes")) {
 			state->state = PARSE_TEXTBOXES;
 		} else {
 			state->prev_state = state->state;
@@ -327,14 +340,14 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_SIMULATION_SETTINGS:
-		if (!strcmp (name, "ogo:transient")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:transient")) {
 			state->state = PARSE_TRANSIENT_SETTINGS;
-		} else if ( !strcmp (name,"ogo:ac")) {
+		} else if ( !xmlStrcmp (name, BAD_CAST"ogo:ac")) {
 			state->state = PARSE_AC_SETTINGS;
-		} else if ( !strcmp (name,"ogo:dc-sweep")) {
+		} else if ( !xmlStrcmp (name, BAD_CAST"ogo:dc-sweep")) {
 			state->state = PARSE_DC_SETTINGS;
 		}
-		else if (!strcmp (name, "ogo:options")) {
+		else if (!xmlStrcmp (name, BAD_CAST"ogo:options")) {
 			state->state = PARSE_OPTION_LIST;
 		} else {
 			state->prev_state = state->state;
@@ -344,22 +357,22 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_TRANSIENT_SETTINGS:
-		if (!strcmp (name, "ogo:enabled")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:enabled")) {
 			state->state = PARSE_TRANSIENT_ENABLED;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:start")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:start")) {
 			state->state = PARSE_TRANSIENT_START;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:stop")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:stop")) {
 			state->state = PARSE_TRANSIENT_STOP;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:step")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:step")) {
 			state->state = PARSE_TRANSIENT_STEP;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:step-enabled")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:step-enabled")) {
 			state->state = PARSE_TRANSIENT_STEP_ENABLE;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:init-conditions")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:init-conditions")) {
 			state->state = PARSE_TRANSIENT_INIT_COND;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -370,16 +383,16 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_AC_SETTINGS:
-		if (!strcmp (name, "ogo:enabled")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:enabled")) {
 			state->state = PARSE_AC_ENABLED;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:npoints")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:npoints")) {
 			state->state = PARSE_AC_NPOINTS;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:start")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:start")) {
 			state->state = PARSE_AC_START;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:stop")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:stop")) {
 			state->state = PARSE_AC_STOP;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -390,31 +403,31 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_DC_SETTINGS:
-		if (!strcmp (name, "ogo:enabled")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:enabled")) {
 			state->state = PARSE_DC_ENABLED;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:vsrc1")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:vsrc1")) {
 			state->state = PARSE_DC_VSRC1;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:start1")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:start1")) {
 			state->state = PARSE_DC_START1;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:stop1")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:stop1")) {
 			state->state = PARSE_DC_STOP1;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:step1")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:step1")) {
 			state->state = PARSE_DC_STEP1;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:vsrc2")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:vsrc2")) {
 			state->state = PARSE_DC_VSRC2;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:start2")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:start2")) {
 			state->state = PARSE_DC_START2;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:stop2")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:stop2")) {
 			state->state = PARSE_DC_STOP2;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:step2")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:step2")) {
 			state->state = PARSE_DC_STEP2;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -425,7 +438,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_OPTION_LIST:
-		if (!strcmp (name, "ogo:option")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:option")) {
 			state->state = PARSE_OPTION;
 			state->option= g_new0(SimOption,1);
 			g_string_truncate (state->content, 0);
@@ -436,10 +449,10 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_OPTION:
-		if (!strcmp (name, "ogo:name")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:name")) {
 			state->state = PARSE_OPTION_NAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:value")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:value")) {
 			state->state = PARSE_OPTION_VALUE;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -450,7 +463,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 
 		break;
 	case PARSE_PARTS:
-		if (!strcmp (name, "ogo:part")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:part")) {
 			state->state = PARSE_PART;
 			state->part = g_new0 (LibraryPart, 1);
 			state->rotation = 0;
@@ -464,36 +477,36 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_PART:
-		if (!strcmp (name, "ogo:name")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:name")) {
 			state->state = PARSE_PART_NAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:library")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:library")) {
 			state->state = PARSE_PART_LIBNAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:refdes")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:refdes")) {
 			state->state = PARSE_PART_REFDES;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:position")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:position")) {
 			state->state = PARSE_PART_POSITION;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:rotation")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:rotation")) {
 			state->state = PARSE_PART_ROTATION;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:flip")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:flip")) {
 			state->state = PARSE_PART_FLIP;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:template")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:template")) {
 			state->state = PARSE_PART_TEMPLATE;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:model")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:model")) {
 			state->state = PARSE_PART_MODEL;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:symbol")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:symbol")) {
 			state->state = PARSE_PART_SYMNAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:labels")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:labels")) {
 			state->state = PARSE_PART_LABELS;
-		} else if (!strcmp (name, "ogo:properties")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:properties")) {
 			state->state = PARSE_PART_PROPERTIES;
 		} else {
 			state->prev_state = state->state;
@@ -502,7 +515,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_PART_LABELS:
-		if (!strcmp (name, "ogo:label")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:label")) {
 			state->state = PARSE_PART_LABEL;
 			state->label = g_new0 (PartLabel, 1);
 		} else {
@@ -512,13 +525,13 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_PART_LABEL:
-		if (!strcmp (name, "ogo:name")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:name")) {
 			state->state = PARSE_PART_LABEL_NAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:text")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:text")) {
 			state->state = PARSE_PART_LABEL_TEXT;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:position")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:position")) {
 			state->state = PARSE_PART_LABEL_POS;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -529,7 +542,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_PART_PROPERTIES:
-		if (!strcmp (name, "ogo:property")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:property")) {
 			state->state = PARSE_PART_PROPERTY;
 			state->property = g_new0 (Property, 1);
 		} else {
@@ -539,10 +552,10 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_PART_PROPERTY:
-		if (!strcmp (name, "ogo:name")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:name")) {
 			state->state = PARSE_PART_PROPERTY_NAME;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:value")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:value")) {
 			state->state = PARSE_PART_PROPERTY_VALUE;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -554,7 +567,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 
 
 	case PARSE_WIRES:
-		if (!strcmp (name, "ogo:wire")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:wire")) {
 			state->state = PARSE_WIRE;
 		} else {
 			state->prev_state = state->state;
@@ -563,7 +576,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_WIRE:
-		if (!strcmp (name, "ogo:points")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:points")) {
 			state->state = PARSE_WIRE_POINTS;
 			g_string_truncate (state->content, 0);
 		} else {
@@ -574,7 +587,7 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		break;
 
 	case PARSE_TEXTBOXES:
-		if (!strcmp (name, "ogo:textbox")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:textbox")) {
 			state->state = PARSE_TEXTBOX;
 		} else {
 			state->prev_state = state->state;
@@ -583,10 +596,10 @@ start_element (ParseState *state, const xmlChar *name, const xmlChar **attrs)
 		}
 		break;
 	case PARSE_TEXTBOX:
-		if (!strcmp (name, "ogo:position")) {
+		if (!xmlStrcmp (name, BAD_CAST"ogo:position")) {
 			state->state = PARSE_TEXTBOX_POSITION;
 			g_string_truncate (state->content, 0);
-		} else if (!strcmp (name, "ogo:text")) {
+		} else if (!xmlStrcmp (name, BAD_CAST"ogo:text")) {
 			state->state = PARSE_TEXTBOX_TEXT;
 			g_string_truncate (state->content, 0);
 		} else {
