@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gtk/gtk.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreemodel.h>
@@ -89,6 +88,7 @@ static void part_browser_setup_libs (Browser *br, GladeXML *gui);
 static void library_switch_cb (GtkWidget *item, Browser *br);
 static void preview_realized (GtkWidget *widget, Browser *br);
 static void wrap_string(char* str, int width);
+static void place_cmd (GtkWidget *widget, Browser *br);
 
 static gboolean
 part_list_filter_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
@@ -139,6 +139,22 @@ part_search_change (GtkWidget *widget, Browser *br)
 	return TRUE;
 }
 
+static void
+part_search_activate (GtkWidget *widget, Browser *br)
+{
+	GtkTreeSelection *selection;
+	GtkTreePath *path;
+
+	path = gtk_tree_path_new_from_string ("0");
+	if (path) {
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (br->list));
+
+		gtk_tree_selection_select_path (selection, path);
+
+		gtk_tree_path_free (path);
+		place_cmd (widget, br);
+	}
+}
 
 static void
 place_cmd (GtkWidget *widget, Browser *br)
@@ -168,6 +184,7 @@ place_cmd (GtkWidget *widget, Browser *br)
 	library_part = library_get_part (br->library, part_name);
 	part = part_new_from_library_part (library_part);
 	if (!part) {
+		oregano_error(_("Unable to load required part"));
 		return;
 	}
 
@@ -380,8 +397,10 @@ part_browser_dnd (GtkSelectionData *selection_data, int x, int y)
 
 	library_part = library_get_part (data->br->library, data->part_name);
 	part = part_new_from_library_part (library_part);
-	if (!part)
+	if (!part) {
+		oregano_error(_("Unable to load required part"));
 		return;
+	}
 
 	item_data_set_pos (ITEM_DATA (part), &pos);
 
@@ -474,10 +493,10 @@ part_browser_create (SchematicView *schematic_view)
 	if (!g_file_test (OREGANO_GLADEDIR "/part-browser.glade2",
 		    G_FILE_TEST_EXISTS)) {
 		msg = g_strdup_printf (
-			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 			OREGANO_GLADEDIR "/part-browser.glade2");
 
-		oregano_error (msg);
+		oregano_error_with_title (_("Could not create part browser"), msg);
 		g_free (msg);
 		return NULL;
 	}
@@ -485,7 +504,7 @@ part_browser_create (SchematicView *schematic_view)
 	gui = glade_xml_new (OREGANO_GLADEDIR "/part-browser.glade2",
 		"part_browser_vbox", GETTEXT_PACKAGE);
 	if (!gui) {
-		oregano_error (_("Could not create part browser."));
+		oregano_error (_("Could not create part browser"));
 		return NULL;
 	}
 
@@ -549,6 +568,9 @@ part_browser_create (SchematicView *schematic_view)
 
 	g_signal_connect (G_OBJECT (br->filter_entry), "changed",
 		G_CALLBACK (part_search_change), br);
+	g_signal_connect (G_OBJECT (br->filter_entry), "activate",
+		G_CALLBACK (part_search_activate), br);
+
 	/* Buttons. */
 	w = glade_xml_get_widget (gui, "place_button");
 	g_signal_connect (G_OBJECT (w), "clicked",
@@ -566,7 +588,7 @@ part_browser_create (SchematicView *schematic_view)
 	br->real_model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
 	cell_text = gtk_cell_renderer_text_new ();
 	cell_column = gtk_tree_view_column_new_with_attributes (
-		_(" "), cell_text, "text", 0, NULL);
+		" ", cell_text, "text", 0, NULL);
 
 	/* Create the sort model for the items, this sort the real model */
 	br->sort_model = gtk_tree_model_sort_new_with_model (
