@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001	Richard Hult
- * Copyright (C) 2003,2005	LUGFI
+ * Copyright (C) 2003,2006	LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <math.h>
@@ -42,15 +41,11 @@
 #include "plot.h"
 #include "smallicon.h"
 
-#include "gtkcairoplot.h"
-#include "gtkcairoplotview.h"
-#include "gtkcairoplotitems.h"
-#include "gtkcairoplotmodel.h"
+#include "gplot.h"
+#include "gplotfunction.h"
+#include "gplotlines.h"
+#include "plot-add-function.h"
 
-/*
- * Unused header
-#include "pixmaps/mini_icon_plot.xpm"
-*/
 #define PLOT_PADDING_X 50
 #define PLOT_PADDING_Y 40
 #define PLOT_WIDTH 400
@@ -71,17 +66,25 @@ const gchar *UPSCRIPT_FONT = N_("Sans 8");
 #define PLOT_AXIS_COLOR "black"
 #define PLOT_CURVE_COLOR "medium sea green"
 
-static int n_curve_colors = 5;
+static int n_curve_colors = 6;
 static char *plot_curve_colors[] = {
-	"medium sea green",
-	"royal blue",
-	"firebrick",
-	"gold",
-	"turquoise",
+	"white",
+	"blue",
+	"green",
+	"red",
+	"yellow",
+	"cyan",
 	0
 };
 
-static gdouble x_min, x_max;
+/*static RGB plot_curve_colors_rgb[] = {
+	{1, 1, 1},
+	{0, 0, 1},
+	{0, 1, 0},
+	{1, 0, 0},
+	{1, 1, 0},
+	{0, 1, 1}
+};*/
 
 /* Hack! */
 #ifndef G_FUNC
@@ -95,9 +98,6 @@ typedef struct {
 	GtkWidget *combobox;
 
 	GtkWidget *plot;
-	GtkCairoPlotView *plot_view;
-	GtkCairoPlotViewItem *plot_draw;
-	GtkCairoPlotModel *plot_model;
 
 	gboolean show_cursor;
 
@@ -114,9 +114,6 @@ typedef struct {
 	gint width;  /* width of the plot, excluding */
 	gint height; /* axes, titles and padding etc */
 
-	gdouble x_factor,x_scale;
-	gdouble y_factor,y_scale;
-
 	gdouble plot_min, plot_max;
 	gdouble x_min,x_max;
 
@@ -133,23 +130,18 @@ typedef enum {
 } AxisType;
 
 static GtkWidget *plot_window_create (Plot *plot);
-static void make_plot (Plot *plot, gint plot_number);
 static void destroy_window (GtkWidget *widget, Plot *plot);
+static void zoom_100 (GtkWidget *widget, Plot *plot);
+static void zoom_region (GtkWidget *widget, Plot *plot);
+static void zoom_pan (GtkWidget *widget, Plot *plot);
 static void destroy_plot (Plot *plot);
 static gint delete_event_cb (GtkWidget *widget, GdkEvent *event, Plot *plot);
-static void getbins (gdouble, gdouble, gint, gdouble *, gdouble *, gint *,
-	gdouble *);
 static void plot_canvas_movement(GtkWidget *, GdkEventMotion *, Plot *);
 static void plot_draw_axis (Plot *, AxisType, double, double);
 
-static void plot_zoom_50_cmd (GtkWidget *widget, Plot *plot);
-static void plot_zoom_75_cmd (GtkWidget *widget, Plot *plot);
-static void plot_zoom_100_cmd (GtkWidget *widget, Plot *plot);
-static void plot_zoom_125_cmd (GtkWidget *widget, Plot *plot);
-static void plot_zoom_150_cmd (GtkWidget *widget, Plot *plot);
-static void plot_zoom_200_cmd (GtkWidget *widget, Plot *plot);
 static void plot_toggle_cross (GtkWidget *widget, Plot *plot);
 static void plot_export (GtkWidget *widget, Plot *plot);
+static void add_function (GtkWidget *widget, Plot *plot);
 
 
 static GnomeUIInfo plot_file_menu[] =
@@ -161,6 +153,8 @@ static GnomeUIInfo plot_file_menu[] =
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_NONE(N_("Export plot"),
 		N_("Show the export menu"), plot_export),
+	GNOMEUIINFO_ITEM_NONE(N_("Add Function"),
+		N_("Add new function to the graph"), add_function),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_CLOSE_ITEM(destroy_window,NULL),
 	GNOMEUIINFO_END
@@ -172,7 +166,7 @@ static GnomeUIInfo plot_zoom_menu [] = {
 //	GNOMEUIINFO_ITEM_NONE(N_("75%"),
 //		N_("Set the zoom factor to 75%"), plot_zoom_75_cmd),
 	{ GNOME_APP_UI_ITEM, N_("100%"),
-	  N_("Set the zoom factor to 100%"), plot_zoom_100_cmd, NULL, NULL, 0,
+	  N_("Set the zoom factor to 100%"), NULL, NULL, NULL, 0,
 	  0, '2', 0 },
 //	GNOMEUIINFO_ITEM_NONE(N_("125%"),
 //		N_("Set the zoom factor to 125%"), plot_zoom_125_cmd),
@@ -216,6 +210,8 @@ gchar *tmp;
 
 	if (!strcmp (str, "voltage")) {
 		tmp = g_strdup ("Volt");
+	} else if (!strcmp (str, "db") ) {
+		tmp = g_strdup ("db");
 	} else if (!strcmp (str, "time") ) {
 		tmp = g_strdup ("s");
 	} else if (!strcmp (str, "frequency") ) {
@@ -254,26 +250,53 @@ destroy_window(GtkWidget *widget, Plot *plot)
 }
 
 static void
-show_plot (Plot *plot)
+on_plot_selected (GtkCellRendererToggle *cell_renderer, gchar *path, Plot *plot)
 {
-	if (plot) {
-		destroy_plot (plot);
-	}
+	GPlotFunction *f;
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	GtkTreeView *treeview;
+	gboolean activo;
 
-	make_plot (plot, plot->selected);
+	treeview = GTK_TREE_VIEW(gtk_object_get_data(GTK_OBJECT(plot->window), "clist"));
+
+	model = gtk_tree_view_get_model (treeview);
+	if (!gtk_tree_model_get_iter_from_string (model , &iter, path))
+		return;
+
+	gtk_tree_model_get (model, &iter, 0, &activo, 4, &f, -1);
+	activo = !activo;
+	gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 0, activo, -1);
+
+	g_object_set (G_OBJECT (f), "visible", activo, NULL);
+
+	gtk_widget_queue_draw (plot->plot);
 }
 
-static gboolean
-plot_selected(GtkWidget *widget, GdkEventButton *event, Plot *plot)
+static GPlotFunction*
+create_plot_function_from_simulation_data (guint i, SimulationData *current)
 {
-	plot->selected = 0;
-	if (plot->ytitle) {
-		g_free (plot->ytitle);
+	double *X;
+	double *Y;
+	double data;
+	guint len, j;
+
+	len = current->data[i]->len;
+	X = g_new0 (double, len);
+	Y = g_new0 (double, len);
+	
+	for (j = 0; j < len; j++) {
+		Y[j] = g_array_index (current->data[i], double, j);
+	
+		data = g_array_index (current->data[0], double, j);
+		
+		/*if (plot->logx)
+			data = log10 (data);
+		*/
+		X[j] = data;
 	}
 
-	plot->ytitle = get_variable_units(plot->current->var_units[plot->selected+1]);
-	show_plot (plot);
-	return TRUE;
+	return g_plot_lines_new (X, Y, len);
 }
 
 static void
@@ -284,15 +307,15 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 	GtkWidget *entry;
 	GtkTreeView *list;
 	GtkTreeModel *model;
-	GtkTreeIter iter;
+	GtkTreeIter parent_nodes, parent_functions;
 	GList *analysis;
 	SimulationData *sdat;
 
-	list = GTK_TREE_VIEW(gtk_object_get_data(GTK_OBJECT (plot->window), "clist"));
+	list = GTK_TREE_VIEW (gtk_object_get_data (GTK_OBJECT (plot->window), "clist"));
 	entry = GTK_COMBO (plot->combobox)->entry;
 
-	ca = gtk_entry_get_text( GTK_ENTRY (entry));
-	g_object_set (G_OBJECT (plot->plot_model), "title", ca, NULL);
+	ca = gtk_entry_get_text (GTK_ENTRY (entry));
+
 	plot->current = NULL;
 	for (analysis = plot->sim->analysis; analysis; analysis = analysis->next) {
 		sdat = SIM_DATA (analysis->data);
@@ -304,229 +327,99 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 
 	if (plot->current == NULL) {
 		/* Simulation failed? */
-		//g_warning("No hay datos de la simulacion!!\n");
-		g_warning (_("No data for the Simulation !!\n"));
+		g_warning (_("The simulation produced no data!!\n"));
 		return;
 	}
 
 	g_free (plot->xtitle);
 	plot->xtitle = get_variable_units (plot->current->var_units[0]);
+	g_free (plot->ytitle);
+	plot->ytitle = get_variable_units (plot->current->var_units[1]);
 
 	g_free (plot->title);
-	plot->title = g_strdup_printf(_("Plot - %s"),
+	plot->title = g_strdup_printf (_("Plot - %s"),
 		sim_engine_analysis_name (plot->current));
-	g_object_set (G_OBJECT (plot->plot_model),
-		"title", plot->title,
-		"x-unit", plot->xtitle,
-		"y-unit", plot->ytitle,
-		NULL);
-
 
 	/*  Set the variable names in the list  */
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(list));
-	//model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(sort));
-	gtk_list_store_clear(GTK_LIST_STORE(model));
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
+	gtk_tree_store_clear (GTK_TREE_STORE (model));
+
+	/* Create root nodes */
+	gtk_tree_store_append (GTK_TREE_STORE (model), &parent_nodes, NULL);
+	gtk_tree_store_set (GTK_TREE_STORE (model), &parent_nodes, 0, FALSE, 1, _("Nodes"), 2, FALSE, 3, "white", -1);
+
+	gtk_tree_store_append (GTK_TREE_STORE (model), &parent_functions, NULL);
+	gtk_tree_store_set (GTK_TREE_STORE (model), &parent_functions, 0, NULL, 1, _("Functions"), 2, FALSE, 3, "white", -1);
+
+	g_plot_set_axis_labels (GPLOT (plot->plot), plot->xtitle, plot->ytitle);
+	g_plot_clear (GPLOT (plot->plot));
+
 	for (i = 1; i < plot->current->n_variables; i++) {
+		GtkTreeIter iter;
+		GPlotFunction *f;
+
 		if (plot->current->type != DC_TRANSFER) {
 			if (strchr(plot->current->var_names[i], '#') == NULL) {
-				gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-				gtk_list_store_set(GTK_LIST_STORE(model),
-					&iter, 0, plot->current->var_names[i],
+				f = create_plot_function_from_simulation_data (i, plot->current);
+				g_object_set (G_OBJECT (f), "visible", FALSE, NULL);
+				g_plot_add_function (GPLOT (plot->plot), f);
+				gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &parent_nodes);
+				gtk_tree_store_set (GTK_TREE_STORE (model),
+					&iter,
+				 	0, FALSE, 
+					1, plot->current->var_names[i],
+				 	2, TRUE,
+					3, "white",
+					4, f,
 					-1);
 			}
 		} else {
-			gtk_list_store_append(GTK_LIST_STORE(model), &iter);
-			gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0,
-				plot->current->var_names[i], -1);
+			f = create_plot_function_from_simulation_data (i, plot->current);
+			g_object_set (G_OBJECT (f), "visible", FALSE, NULL);
+			g_plot_add_function (GPLOT (plot->plot), f);
+			gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &parent_nodes);
+			gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
+				0, FALSE, 
+				1, plot->current->var_names[i],
+			 	2, TRUE,
+				3, "white",
+				4, f,
+			 	-1);
 		}
 	}
-}
 
-static void
-destroy_plot (Plot *plot)
-{
-	// FIXME
-	/* Aca va object_destroy porque el Canvas usa destroy!! */
-	//if (plot->axis_group) gtk_object_destroy (GTK_OBJECT (plot->axis_group));
-	//if (plot->plot_group) gtk_object_destroy (GTK_OBJECT (plot->plot_group));
-
-	//plot->axis_group = NULL;
-	//plot->plot_group = NULL;
-	/* Was destroyed with group */
-	//plot->x_cursor = NULL;
-	//plot->y_cursor = NULL;
+	gtk_widget_queue_draw (plot->plot);
 }
 
 static void
 plot_canvas_movement (GtkWidget *w, GdkEventMotion *event, Plot *plot)
 {
 	gchar *coord;
-	gdouble x,y, x1, y1;
-	
+	gdouble x,y;
+
 	x = event->x;
 	y = event->y;
 
-	gtk_cairo_plot_view_get_point (plot->plot_view, plot->plot_model, x, y, &x1, &y1);
-	coord = g_strdup_printf ("(%g, %g)", x1, y1);
+	g_plot_window_to_device (GPLOT (plot->plot), &x, &y);
+
+	coord = g_strdup_printf ("(%g, %g)", x, y);
 
 	gtk_entry_set_text (GTK_ENTRY (plot->coord), coord);
 
 	g_free (coord);
 }
 
-static void
-make_plot (Plot *plot, gint plot_number)
-{
-	GtkTreeView *clist;
-	GtkTreeModel *model; //, *sort;
-
-	GtkTreeSelection *selection;
-	GList *sel, *l_iter;
-
-	gchar *xtitle, *ytitle, *title;
-
-	double plot_title_width, plot_title_height;
-	double y_factor, y;
-	double x_factor;
-	double y_min, y_max;
-	gint   i, j, k, npts, n_curve;
-	double data, data1;
-	char   *ysc=0,*xsc=0;
-	gdouble sx,sy,ex,ey;
-	gdouble xmin, xmax;
-	gdouble ymin, ymax;
-
-	clist = GTK_TREE_VIEW(gtk_object_get_data(GTK_OBJECT(plot->window), "clist"));
-	y_min = 1.0e20;
-	y_max =-1.0e20;
-	y = 0.0;
-
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(clist));
-
-	selection = gtk_tree_view_get_selection(clist);
-	sel = gtk_tree_selection_get_selected_rows(selection, &model);
-
-	l_iter = sel;
-	while (l_iter) {
-		gint *id = gtk_tree_path_get_indices(l_iter->data);
-		i = id[0] + 1;
-		y = plot->current->min_data[i];
-		if (y_min>y)
-			y_min=y;
-		y = plot->current->max_data[i];
-		if (y_max < y)
-			y_max = y;
-
-		l_iter = l_iter->next;
-	}
-
-	plot->logx = FALSE;
-	if (plot->current->type == AC) {
-		if (!strcmp (sim_settings_get_ac_type (plot->sim->sim_settings), "DEC"))
-			plot->logx = TRUE;
-	}
-
-	if (y_max == y_min) {
-		plot->plot_max = (y_max==0.0 ? 1.0 : 1.1 * y_max);
-		plot->plot_min = (y_max==0.0 ? -1.0 : 0.9 * y_max);
-	} else {
-		gdouble interval = (y_max - y_min);
-		plot->plot_max = y_max + 0.1 * interval;
-		plot->plot_min = y_min - 0.1 * interval;
-	}
-
-	if (fabs(plot->plot_max) > fabs(plot->plot_min)) {
-		sx = plot->plot_max;
-	} else {
-		sx = plot->plot_min;
-	}
-
-/*	get_order_of_magnitude(sx, &sy, &ey);
-	if (ey != 0.0) {
-		sy = pow (10.0, ey);
-		ysc = g_strdup_printf("%.1e", sy);
-	} else {
-		sy = 1.0;
-	}
-*/
-	plot->y_scale = sy;
-
-	x_min = plot->current->min_data[0];
-	x_max = plot->current->max_data[0];
-
-/*	get_order_of_magnitude(x_max, &sx, &ex);
-	if (ex != 0.0) {
-		sx = pow(10.0, ex);
-		xsc = g_strdup_printf("%.1e", sx);
-	} else
-		sx = 1.0;
-*/
-	plot->x_scale = sx;
-	if (plot->logx) {
-		x_min = log10(x_min);
-		x_max = log10(x_max);
-		plot->x_scale = 1.0;
-	}
-
-	/*
-	 * 2. Plot the curve, using the calculated scale factors.
-	 */
-	n_curve = 0;
-	l_iter = sel;
-	gtk_cairo_plot_model_clear (plot->plot_model);
-	while (l_iter) {
-		gint *id = gtk_tree_path_get_indices(l_iter->data);
-		gdouble text_height;
-		plot_number = id[0]+1;
-
-		for (j = 0; j < plot->current->data[plot_number]->len; j++) {
-			/* Loop while the step is positive in the X axis. */
-			Point p;
-			data = g_array_index (
-				plot->current->data[plot_number],
-				double, j);
-			p.y = data;
-
-			data = g_array_index (plot->current->data[0], double, j);
-			/* TODO : que lo haga el plot view! */
-			if (plot->logx)
-				data = log10 (data);
-			p.x = data;
-			gtk_cairo_plot_model_add_point (plot->plot_model, plot->current->var_names[plot_number], p);
-		}
-
-		g_object_set (G_OBJECT (plot->plot_model), "logx", plot->logx, NULL);
-		n_curve++;
-		l_iter = l_iter->next;
-	}
-
-	gtk_cairo_plot_model_get_x_minmax (plot->plot_model, &xmin, &xmax);
-	gtk_cairo_plot_model_get_y_minmax (plot->plot_model, &ymin, &ymax);
-	gtk_cairo_plot_item_draw_set_scroll_region (
-		GTK_CAIRO_PLOT_ITEM_DRAW (plot->plot_draw),
-		xmin, xmax, ymin, ymax);
-}
-
 static GtkWidget *
 plot_window_create (Plot *plot)
 {
 	GtkTreeView *list;
-	GtkListStore *list_model;
+	GtkTreeStore *tree_model;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
-	GtkTreeSelection *selection;
 
 	GtkWidget *outer_table, *window, *button, *plot_scrolled;
-	GtkStyle *style;
-	GdkColormap *colormap;
-	/*
-	 * Unused variables
-	GdkPixmap *icon;
-	GdkBitmap *icon_mask;
-	*/
 	GladeXML *gui;
 	gchar *msg;
-	GtkCairoPlotViewItem *plot_title;
 
 	window = gnome_app_new("plot", _("Oregano - Plot"));
 
@@ -538,9 +431,9 @@ plot_window_create (Plot *plot)
 	if (!g_file_test (OREGANO_GLADEDIR "/plot-window.glade2",
 		    G_FILE_TEST_EXISTS)) {
 		msg = g_strdup_printf (
-			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 			OREGANO_GLADEDIR "/plot-window.glade2");
-		oregano_error (msg);
+		oregano_error_with_title (_("Could not create plot window."), msg);
 		g_free (msg);
 		return NULL;
 	}
@@ -555,32 +448,16 @@ plot_window_create (Plot *plot)
 	plot_scrolled = plot->canvas = glade_xml_get_widget (gui, "plot_scrolled");
 	plot->coord  = glade_xml_get_widget(gui, "pos_label");
 
-	/* Create the Plot view */
-	plot->plot_model = gtk_cairo_plot_model_new ();
-	g_object_set (G_OBJECT (plot->plot_model), "title", _("Plot"), NULL);
+	plot->plot = g_plot_new ();
 
-	plot->plot_view = gtk_cairo_plot_view_new ();
-	plot->plot_draw = gtk_cairo_plot_view_item_new (GTK_CAIRO_PLOT_ITEM_DRAW_TYPE, 0, 0, 100, 100);
-	plot_title = gtk_cairo_plot_view_item_new (GTK_CAIRO_PLOT_ITEM_TITLE_TYPE, 5, 5, 300, 25);
-	
-	gtk_cairo_plot_view_add_item (plot->plot_view, plot->plot_draw, ITEM_POS_FRONT);
-	
-	/* TODO : Is useful a title in plot area?, is not already in combobox??
-	 * gtk_cairo_plot_view_add_item (plot->plot_view, plot_title, ITEM_POS_FRONT);
-	 */
-
-	gtk_cairo_plot_view_attach (plot->plot_view, plot->plot_draw);
-
-	plot->plot = gtk_cairo_plot_new ();
-	gtk_cairo_plot_set_model (GTK_CAIRO_PLOT (plot->plot), plot->plot_model);
-	gtk_cairo_plot_set_view (GTK_CAIRO_PLOT (plot->plot), plot->plot_view);
-	gtk_widget_set_size_request (plot->plot, 300, 300);
+	gtk_widget_set_size_request (plot->plot, 600, 400);
 	gtk_container_add (GTK_CONTAINER (plot_scrolled), plot->plot);
 
 	g_signal_connect(G_OBJECT (plot->plot),
 		"motion_notify_event",
 		G_CALLBACK(plot_canvas_movement), plot
 	);
+
 	g_object_ref(outer_table);
 	gtk_widget_unparent(outer_table);
 	gnome_app_set_contents(GNOME_APP(window), outer_table);
@@ -594,25 +471,48 @@ plot_window_create (Plot *plot)
 	g_signal_connect(G_OBJECT(button), "clicked",
 		G_CALLBACK(destroy_window), plot);
 
+	button = glade_xml_get_widget (gui, "close");
+	g_signal_connect(G_OBJECT(button), "clicked",
+		G_CALLBACK(destroy_window), plot);
+
+	button = glade_xml_get_widget (gui, "zoom_panning");
+	g_signal_connect(G_OBJECT(button), "clicked",
+		G_CALLBACK(zoom_pan), plot);
+
+	button = glade_xml_get_widget (gui, "zoom_region");
+	g_signal_connect(G_OBJECT(button), "clicked",
+		G_CALLBACK(zoom_region), plot);
+
+	button = glade_xml_get_widget (gui, "zoom_normal");
+	g_signal_connect(G_OBJECT(button), "clicked",
+		G_CALLBACK(zoom_100), plot);
+
 	list = GTK_TREE_VIEW(glade_xml_get_widget (gui, "variable_list"));
-	list_model = gtk_list_store_new(1, G_TYPE_STRING);
+	tree_model = gtk_tree_store_new (5, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER);
+
+	/* One Column with 2 CellRenderer. First the Toggle and next a Text */
+	column = gtk_tree_view_column_new ();
+
+	cell = gtk_cell_renderer_toggle_new ();
+	g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (on_plot_selected), plot);
+	gtk_tree_view_column_pack_start (column, cell, FALSE);
+	gtk_tree_view_column_set_attributes (column, cell, "active", 0, "visible", 2, NULL);
+
 	cell = gtk_cell_renderer_text_new();
-	column = gtk_tree_view_column_new_with_attributes("Variable", cell,
-		"text", 0, NULL);
+	gtk_tree_view_column_pack_start (column, cell, TRUE);
+	gtk_tree_view_column_set_attributes (column, cell, "text", 1, NULL);
+
+	cell = gtk_cell_renderer_text_new();
+	gtk_tree_view_column_pack_start (column, cell, FALSE);
+	gtk_cell_renderer_set_fixed_size (cell, 20, 20);
+	gtk_tree_view_column_set_attributes (column, cell, "background", 3, NULL);
 
-	gtk_tree_view_set_model(list, GTK_TREE_MODEL(list_model));
 	gtk_tree_view_append_column(list, column);
+	gtk_tree_view_set_model(list, GTK_TREE_MODEL(tree_model));
 
 	gtk_object_set_data(GTK_OBJECT(window), "clist", list);
 
-	selection = gtk_tree_view_get_selection(list);
-	gtk_tree_selection_set_mode(selection, GTK_SELECTION_EXTENDED);
-
-	//gtk_widget_set_style (GTK_WIDGET (canvas), style);
-
 	gtk_widget_realize(GTK_WIDGET(window));
-//	icon = gdk_pixmap_create_from_xpm_d(window->window, &icon_mask, NULL, mini_icon_plot_xpm);
-//	set_small_icon (window->window, icon, icon_mask);
 	
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (plot_plot_menu[1].widget), TRUE);
 
@@ -628,10 +528,6 @@ plot_show (SimEngine *engine)
 {
 	GtkEntry *entry;
 	GtkTreeView *list;
-	/*
-	 * Unused variable
-	GtkTreeSelection *selection;
-	*/
 	GList *analysis = NULL;
 	GList *combo_items = NULL;
 	Plot *plot;
@@ -661,35 +557,29 @@ plot_show (SimEngine *engine)
 		SimulationData *sdat = SIM_DATA (analysis->data);
 		gchar *str = sim_engine_analysis_name (sdat);
 		if (sdat->type == OP_POINT) {
-			free(str);
+			free (str);
 			continue;
 		}
 		if (s_current == NULL) {
 			s_current = str;
 			first = sdat;
 		}
-		combo_items = g_list_append(combo_items, str);
+		combo_items = g_list_append (combo_items, str);
 	}
 
-	gtk_combo_set_popdown_strings(GTK_COMBO (plot->combobox), combo_items);
+	gtk_combo_set_popdown_strings (GTK_COMBO (plot->combobox), combo_items);
 
-	entry = GTK_ENTRY(GTK_COMBO(plot->combobox)->entry);
-	g_signal_connect(G_OBJECT (entry), "changed",
-		G_CALLBACK(analysis_selected), plot);
+	entry = GTK_ENTRY (GTK_COMBO (plot->combobox)->entry);
+	g_signal_connect (G_OBJECT (entry), "changed",
+		G_CALLBACK (analysis_selected), plot);
 
 	gtk_entry_set_text (GTK_ENTRY (entry), s_current ? s_current : "?");
 
-	list = GTK_TREE_VIEW(
-		gtk_object_get_data ( GTK_OBJECT (plot->window), "clist"));
+	list = GTK_TREE_VIEW (gtk_object_get_data (GTK_OBJECT (plot->window), "clist"));
 
 	plot->title = g_strdup_printf (_("Plot - %s"), s_current);
 	plot->xtitle = get_variable_units (first ? first->var_units[0] : "##");
-	plot->ytitle = g_strdup (first ? first->var_units[1] : "!!");
-
-	g_object_set (G_OBJECT (plot->plot_model), "title", plot->title, NULL);
-
-	g_signal_connect(G_OBJECT(list), "button_release_event",
-		G_CALLBACK(plot_selected), plot);
+	plot->ytitle = get_variable_units (first ? first->var_units[1] : "!!");
 
 	g_free (s_current);
 
@@ -698,174 +588,97 @@ plot_show (SimEngine *engine)
 	return TRUE;
 }
 
-
-/*
- * GetBins
- *
- *   Author: Carlos
- *   Purpose: Finds out the binning for the scale of the control
- *            Wmin,Wmax       : range of the scale
- *            Nold            : wanted number of bins
- *            BinLow, BinHigh : Optimized low and hig bins for which
- *                              a label is to be drawn
- *            Nbins           : number of bins
- *            Bwidth          : bin width between ticks
- *
- */
-static void
-getbins (gdouble Wmin, gdouble Wmax, gint Nold,
-	 gdouble *BinLow, gdouble *BinHigh, gint *Nbins, gdouble *Bwidth)
-{
-	gint lwid, kwid;
-	gint ntemp = 0;
-	gint jlog  = 0;
-	gdouble siground = 0;
-	gdouble alb, awidth, sigfig,atest;
-
-	gdouble AL = MIN (Wmin, Wmax);
-	gdouble AH = MAX (Wmin, Wmax);
-	if (AL == AH)
-		AH = AL + 1;
-
-/*
- * If Nold  ==  -1, program uses binwidth input from calling routine.
- */
-	if (Nold == -1 && (*Bwidth) > 0)
-		goto L90;
-
-	ntemp = MAX (Nold, 2);
-	if (ntemp < 1)
-		ntemp = 1;
-
-/*
- * Get nominal bin width in exponential form.
- */
-
- L20:
-	awidth = (AH - AL) / ((gdouble)ntemp);
-	if (awidth > 1.e30)
-		goto LOK;
-
-	jlog   = (gint)(log10 (awidth));
-	if (awidth <= 1)
-		jlog--;
-
-	sigfig = awidth * ((gdouble)pow (10, -jlog));
-
-/*
- * Round mantissa up to 1, 2, 2.5, 5, or 10.
- */
-
-	if (sigfig <= 1)
-		siground = 1;
-	else if (sigfig <= 2)
-		siground = 2;
-/*   else if (sigfig <= 2.5)  siground = 2.5;*/
-	else if (sigfig <= 5)
-		siground = 5;
-	else {
-		siground = 1;
-		jlog++;
-	}
-
-	(*Bwidth) = siground * pow (10, jlog);
-
-/*
- * Get new bounds from new width Bwidth.
- */
-
- L90:
-	alb = AL / (*Bwidth);
-	lwid = (gint) (alb);
-	if (alb < 0)
-		lwid--;
-	(*BinLow) = siground*((gdouble)lwid)*pow(10,jlog);
-	alb = AH / (*Bwidth) + 1.00001f;
-	kwid = (gint) alb;
-	if (alb < 0)
-		kwid--;
-	(*BinHigh) = siground * ((gdouble) kwid) * pow (10, jlog);
-	(*Nbins) = kwid - lwid;
-	if (Nold == -1)
-		goto LOK;
-	if (Nold <= 5) { /* Request for one bin is difficult case. */
-		if (Nold > 1 || (*Nbins) == 1)
-			goto LOK;
-
-		(*Bwidth) = (*Bwidth) * 2;
-		(*Nbins) = 1;
-		goto LOK;
-	}
-	if (2 * (*Nbins) == Nold) {
-		ntemp++;
-		goto L20;
-	}
-
- LOK:
-	atest = (*Bwidth) * 0.0001f;
-	if (fabs ((*BinLow) - Wmin)  >= atest) {
-		(*BinLow) += (*Bwidth);
-		(*Nbins)--;
-	}
-
-	if (fabs ((*BinHigh) - Wmax) >= atest) {
-		(*BinHigh) -= (*Bwidth);
-		(*Nbins)--;
-	}
-}
-
-
-static void
-plot_zoom_50_cmd (GtkWidget *widget, Plot *plot)
-{
-	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS(plot->canvas), 0.5);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
-static void
-plot_zoom_75_cmd (GtkWidget *widget, Plot *plot)
-{
-	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (plot->canvas), 0.75);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
-static void 
-plot_zoom_100_cmd (GtkWidget *widget, Plot *plot)
-{
-	gdouble a, b, c, d;
-	gtk_cairo_plot_model_get_x_minmax (plot->plot_model, &a, &b);
-	gtk_cairo_plot_model_get_y_minmax (plot->plot_model, &c, &d);
-	gtk_cairo_plot_view_set_scroll_region (plot->plot_view, a, b, c, d);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
-static void 
-plot_zoom_125_cmd (GtkWidget *widget, Plot *plot)
-{
-	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (plot->canvas), 1.25);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
-static void 
-plot_zoom_150_cmd (GtkWidget *widget, Plot *plot)
-{
-	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (plot->canvas), 1.5);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
-static void 
-plot_zoom_200_cmd (GtkWidget *widget, Plot *plot)
-{
-	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (plot->canvas), 2.0);
-	gtk_widget_queue_draw (plot->canvas);
-}
-
 static void
 plot_toggle_cross (GtkWidget *widget, Plot *plot)
 {
 	plot->show_cursor = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget));
 }
 
+static GPlotFunction*
+create_plot_function_from_data (SimulationFunction *func, SimulationData *current)
+{
+	double *X;
+	double *Y;
+	double data;
+	guint j, len;
+
+	len = current->data[func->first]->len;
+	X = g_new0 (double, len);
+	Y = g_new0 (double, len);
+
+	for (j = 0; j < len; j++) {
+		Y[j] = g_array_index (current->data[func->first], double, j);
+	
+		data = g_array_index (current->data[func->second], double, j);
+		Y[j] = sim_engine_do_function (func->type, Y[j], data);
+		
+		X[j] = g_array_index (current->data[0], double, j);
+	}
+
+	return g_plot_lines_new (X, Y, len);
+}
+
+static void
+add_function (GtkWidget *widget, Plot *plot)
+{
+	GtkTreeView *tree;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GtkTreePath *path;
+	GList *lst;
+
+	plot_add_function_show (plot->sim, plot->current);
+
+	tree = GTK_TREE_VIEW(gtk_object_get_data(GTK_OBJECT (plot->window), "clist"));
+	model = gtk_tree_view_get_model (tree);
+
+	path = gtk_tree_path_new_from_string ("1");
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_path_free (path);
+	
+	gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+
+	gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
+	gtk_tree_store_set(GTK_TREE_STORE(model), &iter, 0, FALSE, 1, _("Functions"), 2, FALSE, 3, "white", -1);
+
+	lst = plot->current->functions;
+	while (lst)	{
+		GPlotFunction *f;
+		GtkTreeIter child;
+		int i;
+		gchar *str, *name1, *name2;
+		SimulationFunction *func = (SimulationFunction *)lst->data;
+	
+		for (i = 1; i < plot->current->n_variables; i++) {
+			if (func->first == i) {
+				name1 = g_strdup (plot->current->var_names[i]);
+			}
+			if (func->second == i) {
+				name2 = g_strdup (plot->current->var_names[i]);
+			}
+		}
+		switch (func->type) {
+			case FUNCTION_MINUS:
+				str = g_strdup_printf ("%s - %s", name1, name2);
+			break;
+			case FUNCTION_TRANSFER:
+				str = g_strdup_printf ("%s(%s, %s)", _("TRANSFER"), name1, name2);
+		}
+
+		f = create_plot_function_from_data (func, plot->current);
+
+		g_plot_add_function (GPLOT (plot->plot), f);
+
+		gtk_tree_store_append(GTK_TREE_STORE(model), &child, &iter);
+		gtk_tree_store_set(GTK_TREE_STORE(model), &child, 0, TRUE, 1, str, 2, TRUE, 3, "white", 4, f, -1);
+
+		lst = lst->next;
+	}
+
+
+	gtk_widget_queue_draw (plot->plot);
+}
+
 static void
 plot_export (GtkWidget *widget, Plot *plot)
 {
@@ -879,9 +692,9 @@ plot_export (GtkWidget *widget, Plot *plot)
 	
 	if (!g_file_test (OREGANO_GLADEDIR "/plot-export.glade2", G_FILE_TEST_EXISTS)) {
 		msg = g_strdup_printf (
-			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 			OREGANO_GLADEDIR "/plot-export.glade2");
-		oregano_error (msg);
+		oregano_error_with_title (_("Could not create plot export window."), msg);
 		g_free (msg);
 		return;
 	}
@@ -903,10 +716,11 @@ plot_export (GtkWidget *widget, Plot *plot)
 		return;
 	}
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (export_png)))
+	format = 0;
+	/*if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (export_png)))
 		format = GTK_CAIRO_PLOT_VIEW_SAVE_PNG;
 	else
-		format = GTK_CAIRO_PLOT_VIEW_SAVE_PS;
+		format = GTK_CAIRO_PLOT_VIEW_SAVE_PS;*/
 
 	fn = dialog_file_open (_("Save PNG"));
 	if (fn == NULL) {
@@ -917,8 +731,24 @@ plot_export (GtkWidget *widget, Plot *plot)
 	w = gtk_spin_button_get_value_as_int (width);
 	h = gtk_spin_button_get_value_as_int (height);
 
-	gtk_cairo_plot_view_save (plot->plot_view,
-		plot->plot_model, w, h, fn, format);
-
 	gtk_widget_destroy (window);
 }
+
+static void
+zoom_100 (GtkWidget *widget, Plot *plot)
+{
+	g_plot_reset_zoom (GPLOT (plot->plot));
+}
+
+static void
+zoom_region (GtkWidget *widget, Plot *plot)
+{
+	g_plot_set_zoom_mode (GPLOT (plot->plot), GPLOT_ZOOM_REGION);
+}
+
+static void
+zoom_pan (GtkWidget *widget, Plot *plot)
+{
+	g_plot_set_zoom_mode (GPLOT (plot->plot), GPLOT_ZOOM_INOUT);
+}
+
