@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <math.h>
 #include <string.h>
 #include <unistd.h>
@@ -60,7 +59,7 @@
 #include "plot.h"
 #include "sheet-item-factory.h"
 #include "part-item.h"
-//#include "netlist-editor.h"
+#include "errors.h"
 #include "node-item.h"
 
 /* remove: */
@@ -249,10 +248,10 @@ properties_cmd (GtkWidget *widget, SchematicView *sv)
 	if (!g_file_test (OREGANO_GLADEDIR "/properties.glade2", G_FILE_TEST_EXISTS)) {
 		gchar *msg;
 		msg = g_strdup_printf (
-			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:</span>\n%s"),
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 			OREGANO_GLADEDIR "/properties.glade2");
 
-		oregano_error (msg);
+		oregano_error_with_title (_("Could not create properties dialog"), msg);
 		g_free (msg);
 		return;
 	}
@@ -315,10 +314,10 @@ page_properties_cmd (GtkWidget *widget, SchematicView *sv)
 	if (!g_file_test (OREGANO_GLADEDIR "/page-properties.glade2", G_FILE_TEST_EXISTS)) {
 		gchar *msg;
 		msg = g_strdup_printf (
-			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 			OREGANO_GLADEDIR "/page-properties.glade2");
 
-		oregano_error (msg);
+		oregano_error_with_title (_("Could not create the page properties dialog"), msg);
 		g_free (msg);
 		return;
 	}
@@ -329,6 +328,8 @@ page_properties_cmd (GtkWidget *widget, SchematicView *sv)
 	);
 
 	win = glade_xml_get_widget (xml, "page_properties");
+
+	// Set the checkboxes according to the options selected
 	fit = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "fit_page"));
 	center_h = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "center_h"));
 	center_v = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "center_v"));
@@ -339,6 +340,7 @@ page_properties_cmd (GtkWidget *widget, SchematicView *sv)
 	
 	btn = gtk_dialog_run (GTK_DIALOG (win));
 
+	// Store the changes
 	if (btn == GTK_RESPONSE_OK) {
 		sv->priv->page.fit_to_page = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fit));
 		sv->priv->page.center_h = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (center_h));
@@ -355,6 +357,7 @@ open_cmd (GtkWidget *widget, SchematicView *sv)
 	SchematicView *new_sv;
 	char *fname;
 	GList *list;
+	GError *error = NULL;
 
 	fname = dialog_open_file (sv);
 	if (fname == NULL)
@@ -374,7 +377,12 @@ open_cmd (GtkWidget *widget, SchematicView *sv)
 	while (gtk_events_pending())
 		gtk_main_iteration();
 
-	new_sm = schematic_read(fname);
+	new_sm = schematic_read(fname, &error);
+
+	if (error != NULL) {
+		oregano_error_with_title (_("Could not load file"), error->message);
+		g_error_free (error);
+	}
 
 	if (new_sm) {
 		if (!new_sv)
@@ -395,7 +403,7 @@ save_cmd (GtkWidget *widget, SchematicView *sv)
 {
 	Schematic *sm;
 	char *filename;
-
+	GError *error = NULL;
 	sm = sv->priv->schematic;
 	filename = schematic_get_filename (sm);
 
@@ -403,12 +411,9 @@ save_cmd (GtkWidget *widget, SchematicView *sv)
 		dialog_save_as (sv);
 		return;
 	} else {
-		if (!schematic_save_file (sm)){
-			char *msg = g_strdup_printf (
-				_("<span weight=\"bold\" size=\"x-large\">Could not save Schematic file\n</span>%s\n"),
-				filename);
-			oregano_error (msg);
-			g_free (msg);
+		if (!schematic_save_file (sm, &error)){
+			oregano_error_with_title (_("Could not save schematic file"), error->message);
+			g_error_free (error);
 		}
 	}
 }
@@ -763,19 +768,13 @@ netlist_cmd (GtkWidget *widget, SchematicView *sv)
 	g_free (netlist_name);
 	
 	if (error != NULL) {
-		if (g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
-				g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_NO_GND) ||
-				g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_IO_ERROR)) {
-			char *str;
-			str = g_strdup_printf (
-				_("<span weight=\"bold\" size=\"x-large\">Could not create a netlist</span>\n\n%s"),
-				error->message);
-			oregano_error (str);
-			g_free (str);
+		if (g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
+				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_GND) ||
+				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_IO_ERROR)) {
+			oregano_error_with_title (_("Could not create a netlist"), error->message);
 			g_clear_error (&error);
 		} else {
-			oregano_error (
-				_("<span weight=\"bold\" size=\"x-large\">Unspected error!!!</span>"));
+			oregano_error (_("An unexpected error has occurred"));
 		}
 		return;
 	}
@@ -890,19 +889,13 @@ simulate_cmd (GtkWidget *widget, SchematicView *sv)
 	filename = nl_generate (sm, NULL, &error);
 
 	if (error != NULL) {
-		if (g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
-				g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_NO_GND) ||
-				g_error_matches (error, OREGANO_SIMULATE_ERROR, OREGANO_SIMULATE_ERROR_IO_ERROR)) {
-			char *str;
-			str = g_strdup_printf (
-				_("<span weight=\"bold\" size=\"x-large\">Could not create a netlist</span>\n\n%s"),
-				error->message);
-			oregano_error (str);
-			g_free (str);
-			g_clear_error (&error);
+		if (g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_CLAMP) ||
+				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_NO_GND) ||
+				g_error_matches (error, OREGANO_ERROR, OREGANO_SIMULATE_ERROR_IO_ERROR)) {
+			oregano_error_with_title (_("Could not create a netlist"), error->message);
+			g_error_free (error);
 		} else {
-			oregano_error (
-				_("<span weight=\"bold\" size=\"x-large\">Unspected error!!!</span>"));
+			oregano_error (_("An unexpected error has occurred"));
 		}
 		return;
 	}
@@ -1537,14 +1530,15 @@ can_close (SchematicView *sv)
 	GtkWidget *dialog, *lb;
 	gchar *text, *filename;
 	gint result;
+	GError *error = NULL;
 
 	if (!schematic_is_dirty (schematic_view_get_schematic (sv)))
 		return TRUE;
 	
 	filename = schematic_get_filename (sv->priv->schematic);
 	text = g_strdup_printf (
-		_("<span weight=\"bold\" size=\"x-large\">Schematic %s has unsaved changes</span>\n\n"
-			"Do you want to save them?"),
+		_("<span weight=\"bold\" size=\"large\">Save changes to schematic %s before closing?</span>\n\n"
+			"If you don't save, all changes since you last saved will be permanently lost."),
 			filename ?  g_basename (filename) : NULL );
 
 	dialog = gtk_message_dialog_new_with_markup (
@@ -1555,9 +1549,10 @@ can_close (SchematicView *sv)
 		_(text), NULL);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+		_("Close _without Saving"),
+		GTK_RESPONSE_NO,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		GTK_STOCK_NO, GTK_RESPONSE_NO,
-		GTK_STOCK_YES, GTK_RESPONSE_YES,
+		GTK_STOCK_SAVE, GTK_RESPONSE_YES,
 		NULL);
 
 	g_free (text);
@@ -1568,7 +1563,7 @@ can_close (SchematicView *sv)
 
 	switch (result) {
 		case GTK_RESPONSE_YES:
-			schematic_save_file (schematic_view_get_schematic (sv));
+			schematic_save_file (schematic_view_get_schematic (sv), &error);
 		break;
 		case GTK_RESPONSE_NO:
 			schematic_set_dirty (schematic_view_get_schematic (sv), FALSE);
@@ -1709,6 +1704,19 @@ sheet_event_callback (GtkWidget *widget, GdkEvent *event, SchematicView *sv)
 
 		break;
 
+	case GDK_SCROLL:
+		if (((GdkEventScroll *)event)->direction == GDK_SCROLL_UP) {
+			double zoom;
+			sheet_get_zoom (sv->priv->sheet, &zoom);
+			if (zoom < ZOOM_MAX)
+				zoom_in_cmd (widget, sv);
+		} else if (((GdkEventScroll *)event)->direction == GDK_SCROLL_DOWN) {
+			double zoom;
+			sheet_get_zoom (sv->priv->sheet, &zoom);
+			if (zoom > ZOOM_MIN)
+			zoom_out_cmd (widget, sv);
+		}
+		break;
 	case GDK_KEY_PRESS:
 		switch (event->key.keyval) {
 		case GDK_R:
@@ -1825,6 +1833,7 @@ data_received (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 	gchar **files;
 	GtkTargetEntry *array;
 	guint narray;
+	GError *error = NULL;
 
 	/*
 	 * Extract the filenames from the URI-list we recieved.
@@ -1852,7 +1861,7 @@ data_received (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 
 					gchar *fname = files[i];
 
-					new_sm = schematic_read (fname);
+					new_sm = schematic_read (fname, &error);
 					if (new_sm) {
 							SchematicView *new_view;
 						new_view = schematic_view_new (new_sm);
@@ -2460,10 +2469,10 @@ schematic_view_log_show (SchematicView *sv, gboolean explicit)
 
 		if (!g_file_test (OREGANO_GLADEDIR "/log-window.glade2", G_FILE_TEST_EXISTS)) {
 			msg = g_strdup_printf (
-				_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
+				_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
 				OREGANO_GLADEDIR "/log-window.glade2");
 
-			oregano_error (msg);
+			oregano_error_with_title ( _("Could not create the log window"), msg);
 			g_free (msg);
 			return;
 		}
@@ -2474,7 +2483,7 @@ schematic_view_log_show (SchematicView *sv, gboolean explicit)
 			NULL, NULL);
 
 		if (!sv->priv->log_gui) {
-			oregano_error (_("<span weight=\"bold\">Could not create log window.</span>"));
+			oregano_error (_("Could not create the log window"));
 			return;
 		}
 
