@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,7 +31,6 @@
  * Simulate engine class, interface to SPICE.
  */
 
-#include <config.h>
 #include <gnome.h>
 #include <stdlib.h>
 #include <string.h>
@@ -102,7 +101,11 @@ static char *analisys_tags[] = {
 
 #define GNUCAP_TITLE "#"
 
-typedef struct _gnucap_variable_ {
+//typedef struct _gnucap_variable_ {
+//	gchar *name;
+	//gchar *unit;
+//} GCap_Variable;
+typedef struct {
 	gchar *name;
 	//gchar *unit;
 } GCap_Variable;
@@ -265,23 +268,23 @@ sim_engine_start_with_file (SimEngine *engine, const gchar *netlist)
 	/* TODO Would be recomendable to use pthread? */
 	engine->child_pid = fork();
 	if (engine->child_pid == 0) {
+		setpgrp ();
 		/* Now oregano.simtype has gnucap or ngspice */
 		gchar *simexec = oregano.simexec;
         /* !!!!!!!!!!! "-s" "-n" */
 		gchar *args[4] = { simexec, oregano.simtype, (gchar *)netlist, NULL };
-
-
+	
 		/* The child executes here. */
-		/*netlist_fd = open (netlist, O_RDONLY);
+		netlist_fd = open (netlist, O_RDONLY);
 		if (netlist_fd == -1)
-			g_error ("Error opening netlist.");*/
+			g_error ("Error opening netlist.");
 
 		close (engine->to_child[WRITE]);
 		close (engine->to_parent[READ]);
 		close (engine->to_parent_error[READ]);
 
-/*		dup2 (netlist_fd, STDIN_FILENO);
-		close (netlist_fd);*/
+		dup2 (netlist_fd, STDIN_FILENO);
+		close (netlist_fd);
 		close (engine->to_child[READ]);
 
 		/* Map stderr and stdout to their pipes. */
@@ -293,7 +296,7 @@ sim_engine_start_with_file (SimEngine *engine, const gchar *netlist)
 		//setlocale (LC_NUMERIC, "C");
 
 		/* Execute Sim Engine. */
-		/* SimExec deberia apuntar a oregano_parser con
+		/* SimExec deberia apuntar a oregano_parser.pl con
 		 * path y todo
 		 */
 		execvp(simexec, args);
@@ -357,7 +360,8 @@ sim_engine_stop (SimEngine *engine)
 	engine->data_input_id = 0;
 	engine->error_input_id = 0;
 
-	kill (engine->child_pid, SIGKILL);
+	kill (-engine->child_pid, SIGTERM);
+
 	waitpid (engine->child_pid, &status, WUNTRACED);
 	engine->child_pid = 0;
 
@@ -447,7 +451,7 @@ void _free_variables(GCap_Variable *v, gint count)
 GCap_Variable *_get_variables(gchar *str, gint *count)
 {
 	GCap_Variable *out;
-	/* FIXME hacer mas bonito esto */
+	/* FIXME Improve the code */
 	gchar *tmp[100];
 	gchar *ini, *fin;
 	gint i = 0;
@@ -570,6 +574,7 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 		engine->num_analysis++;
 		sdata->state = STATE_IDLE;
 		sdata->type  = ANALYSIS_UNKNOWN;
+		sdata->functions = NULL;
 
 		/* Calculates the quantity of variables */
 		variables = _get_variables(buf, &n);
@@ -599,19 +604,26 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 		}
 		for(i=0; i<n; i++) {
 			sdata->var_names[i] = g_strdup(variables[i].name);
-			/* FIXME : unit depend of user input !! */
 			switch (sdata->type) {
 			case TRANSIENT:
 				if (i==0)
-					sdata->var_units[i] = g_strdup("time");
-				else
-					sdata->var_units[i] = g_strdup("voltage");
+					sdata->var_units[i] = g_strdup(_("time"));
+				else {
+					if (strstr (sdata->var_names[i], "db") != NULL) {
+						sdata->var_units[i] = g_strdup("db");
+					} else
+						sdata->var_units[i] = g_strdup(_("voltage"));
+				}
 				break;
 			case AC:
 				if (i==0)
-					sdata->var_units[i] = g_strdup("frequency");
-				else
-					sdata->var_units[i] = g_strdup("voltage");
+					sdata->var_units[i] = g_strdup(_("frequency"));
+				else {
+					if (strstr (sdata->var_names[i], "db") != NULL) {
+						sdata->var_units[i] = g_strdup("db");
+					} else
+						sdata->var_units[i] = g_strdup(_("voltage"));
+				}
 				break;
 			default:
 				sdata->var_units[i] = g_strdup("");
@@ -666,7 +678,7 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 		case SENSITIVITY:
 			break;
 		case ANALYSIS_UNKNOWN:
-			g_error("Unknown analysis: %s",analysis);
+			g_error(_("Unknown analysis: %s"),analysis);
 			break;
 		}
 	} else {
@@ -715,7 +727,7 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 			break;
 		default:
 			if (strlen (buf) > 1) {
-				if (strstr (buf,"abort"))
+				if (strstr (buf, _("abort")))
 					sdata->state = STATE_ABORT;
 				schematic_log_append (engine->sm, buf);
 			}
@@ -724,3 +736,27 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 		}
 	}
 }
+
+double
+sim_engine_do_function (SimulationFunctionType type, double first, double second)
+{
+	double outval = 0.0f;
+
+	switch (type) {
+		case FUNCTION_MINUS:
+			outval = first - second;
+		break;
+		case FUNCTION_TRANSFER:
+			if (second < 0.000001f) {
+				/* TODO */
+				if (first < 0)
+					outval = -G_MAXDOUBLE;
+				else
+					outval = G_MAXDOUBLE;
+			} else {
+				outval = first / second;
+			}
+		break;
+	}
+	return outval;
+}
