@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2005  LUGFI
+ * Copyright (C) 2003,2006  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <gnome.h>
@@ -232,6 +231,39 @@ option_setvalue (GtkWidget *w, SimSettings *s)
 //	gnome_property_box_set_modified (GNOME_PROPERTY_BOX (s->pbox), TRUE);
 }
 
+static void
+add_option (GtkWidget *w, SimSettings *s)
+{
+	GtkEntry *entry;
+	GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Add new option"),
+		NULL,
+		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CANCEL,
+		GTK_RESPONSE_REJECT,
+		GTK_STOCK_OK,
+		GTK_RESPONSE_OK,
+		NULL);
+
+	entry = GTK_ENTRY (gtk_entry_new ());
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), GTK_WIDGET (entry));
+	gtk_widget_show (GTK_WIDGET (entry));
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+		GtkTreeIter iter;
+		SimOption *opt = g_new0 (SimOption, 1);
+		opt->name = g_strdup (gtk_entry_get_text (entry));
+		opt->value = g_strdup ("");
+		/* Warning : don't free opt later, is added to the list */
+		sim_settings_add_option (s, opt);
+	
+		gtk_list_store_append (GTK_LIST_STORE (gtk_tree_view_get_model(s->priv->w_opt_list)), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (gtk_tree_view_get_model(s->priv->w_opt_list)), &iter, 0, opt->name, -1);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
+
 static void
 option_remove (GtkWidget *w, SimSettings *s)
 {
@@ -789,8 +821,8 @@ response_callback(GtkDialog *dlg, gint id, Schematic *sm)
 	case GTK_RESPONSE_CANCEL:
 		if (s->priv->trans_enable) {
 			if (sim_settings_get_trans_start (s) >= sim_settings_get_trans_stop (s)) {
-				oregano_error (_("<span size=\"x-large\" weigth=\"bold\">Transient analysis</span>\n\n"
-					"Start time must be less than stop time."));
+				oregano_error_with_title (_("Problem in transient analysis"),
+					_("Start time must be less than stop time."));
 				return;
 			}
 		}
@@ -829,19 +861,24 @@ sim_settings_show (GtkWidget *widget, SchematicView *sv)
 	}
 
 	if (!g_file_test (OREGANO_GLADEDIR "/sim-settings.glade2", G_FILE_TEST_EXISTS)) {
-		oregano_error (_("<span size=\"x-large\" weight=\"bold\">Could not create simulation settings dialog.</span>"));
+		gchar *msg;
+		msg = g_strdup_printf (
+			_("The file %s could not be found. You might need to reinstall Oregano to fix this."),
+			OREGANO_GLADEDIR "/sim-settings.glade2");
+		oregano_error_with_title (_("Could not create simulation settings dialog"), msg);
+		g_free (msg);
 		return;
 	}
 
 	gui = glade_xml_new (OREGANO_GLADEDIR "/sim-settings.glade2", "toplevel", NULL);
 	if (!gui) {
-		oregano_error (_("<span size=\"x-large\" weight=\"bold\">Could not create simulation settings dialog.</sapn>"));
+		oregano_error (_("Could not create simulation settings dialog"));
 		return;
 	}
 
 	toplevel = glade_xml_get_widget (gui, "toplevel");
 	if (!toplevel) {
-		oregano_error (_("<span size=\"x-large\" weight=\"bold\">Could not create simulation settings dialog.</span>"));
+		oregano_error (_("Could not create simulation settings dialog"));
 		return;
 	}
 
@@ -876,9 +913,23 @@ sim_settings_show (GtkWidget *widget, SchematicView *sv)
 	gtk_tree_view_append_column(opt_list, column_option);
 	gtk_tree_view_append_column(opt_list, column_value);
 
-	for (i = 0; default_options[i].name; i++) {
-		gtk_list_store_append(opt_model, &iter);
-		gtk_list_store_set(opt_model, &iter, 0, default_options[i].name, -1);
+	if (s->priv->options == NULL) {
+		/* Load defaults */
+		for (i = 0; default_options[i].name; i++) {
+			gtk_list_store_append(opt_model, &iter);
+			gtk_list_store_set(opt_model, &iter, 0, default_options[i].name, -1);
+		}
+	} else {
+		/* Load schematic options */
+		list = s->priv->options;
+		while (list) {
+			SimOption *so = list->data;
+			if (so) {
+				gtk_list_store_append(opt_model, &iter);
+				gtk_list_store_set(opt_model, &iter, 0, so->name, -1);
+			}
+			list = list->next;
+		}
 	}
 
 	/* Set the optinos already stored */
@@ -897,6 +948,8 @@ sim_settings_show (GtkWidget *widget, SchematicView *sv)
 	g_signal_connect (G_OBJECT(w),"clicked", G_CALLBACK(option_setvalue), s);
 	w = glade_xml_get_widget (gui, "opt_remove");
 	g_signal_connect (G_OBJECT(w),"clicked", G_CALLBACK(option_remove), s);
+	w = glade_xml_get_widget (gui, "add_option");
+	g_signal_connect (G_OBJECT(w),"clicked", G_CALLBACK(add_option), s);
 
 	/* Setup callbacks. */
 	g_signal_connect (G_OBJECT (pbox),
