@@ -19,7 +19,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gnome.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -51,17 +50,6 @@ static void nl_node_traverse (Node *node, GSList **);
 static GSList* nl_get_clamp_parts (NodeStore *store, Node *node);
 static void nl_node_traverse (Node *node, GSList **);
 
-
-GQuark
-oregano_simulate_error_quark (void) 
-{
-	static GQuark err = 0;
-	if (!err) {
-		err = g_quark_from_static_string ("oregano-simulate-error");
-	}
-	return err;
-}
-
 static void
 nl_wire_traverse (Wire *wire, GSList **lst)
 {
@@ -161,7 +149,7 @@ open_nl_file (gchar **name, FILE **f)
 		tmp_filename = g_build_filename (g_get_tmp_dir(), "oregXXXXXX", NULL);
 		fd = mkstemp (tmp_filename);
 		if (fd == -1) {
-			g_warning(N_("Could't generate temp file!!\n"));
+			g_warning(N_("Couldn't generate temporary file.\n"));
 			g_free(tmp_filename);
 			return FALSE;
 		}
@@ -292,7 +280,7 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 	/* Try to open the file.  Return NULL if it fails*/
 	if (open_nl_file(&name, &f) == FALSE ) {
 		g_set_error (error,
-			OREGANO_SIMULATE_ERROR,
+			OREGANO_ERROR,
 			OREGANO_SIMULATE_ERROR_IO_ERROR,
 				_("Possibly due an I/O error.")
 			);
@@ -321,10 +309,10 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 		schematic_log_append (sm, _("No ground node. Aborting.\n"));
 		schematic_log_show (sm);
 		g_set_error (error,
-			OREGANO_SIMULATE_ERROR,
+			OREGANO_ERROR,
 			OREGANO_SIMULATE_ERROR_NO_GND,
 				_("Possibly due to a faulty circuit schematic. Please check that\n"
-				"you have a Ground node and try again.")
+				"you have a ground node and try again.")
 			);
 
 		/* No file will be generated. */
@@ -341,7 +329,7 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 		schematic_log_append (sm, _("No test clamps found. Aborting.\n"));
 		schematic_log_show (sm);
 		g_set_error (error,
-			OREGANO_SIMULATE_ERROR,
+			OREGANO_ERROR,
 			OREGANO_SIMULATE_ERROR_NO_CLAMP,
 				_("Possibly due to a faulty circuit schematic. Please check that\n"
 					"you have one o more test clamps and try again.")
@@ -459,7 +447,7 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 			node_nr = GPOINTER_TO_INT (g_hash_table_lookup (data->pins,
 				&pins[pin_nr]));
 			if (!node_nr) {
-				g_warning ("Couln't find part, pin_nr %d.", pin_nr);
+				g_warning ("Couldn't find part, pin_nr %d.", pin_nr);
 			} else {
 				gchar *tmp;
 				gchar *_tmp;
@@ -544,7 +532,7 @@ void nl_generate_spice (net_out * output, FILE *file, NetlistData * data)
 		   "*\tNGSPICE - NETLIST"
 		   "\n", file);
 	/* Prints Options */
-	fputs (".options NOPAGE\n",file);
+	fputs (".options NOPAGE \n",file);
 
 	while (list) {
 		so = list->data;
@@ -624,7 +612,7 @@ void nl_generate_gnucap (net_out * output, FILE *file, NetlistData * data)
 		   "*\tGNUCAP - NETLIST"
 		   "\n", file);
 	/* Prints Options */
-	fputs (".options OUT=120",file);
+	fputs (".options OUT=120 ",file);
 
 	while (list) {
 		so = list->data;
