@@ -26,21 +26,10 @@
 #ifndef __SIMULATE_H
 #define __SIMULATE_H
 
-#include <config.h>
 #include <gnome.h>
 #include <glib.h>
 #include "schematic.h"
-
-#define OREGANO_SIMULATE_ERROR (oregano_simulate_error_quark())
-
-GQuark oregano_simulate_error_quark (void);
-
-typedef enum {
-	OREGANO_SIMULATE_ERROR_NO_GND,
-	OREGANO_SIMULATE_ERROR_NO_CLAMP,
-	OREGANO_SIMULATE_ERROR_IO_ERROR
-} OREGANO_ERRORS;
-
+#include "errors.h"
 
 /**
  * Please add a real comment. Describe:
