@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001	Richard Hult
- * Copyright (C) 2003,2005	LUGFI
+ * Copyright (C) 2003,2006	LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
 	 * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gtk/gtk.h>
 #include <locale.h>
 #include <glade/glade.h>
@@ -53,7 +52,7 @@ typedef struct {
 } Simulation;
 
 static int progress_bar_timeout_callback (Simulation *s);
-static void cancel_callback (GtkWidget *widget, Simulation *s);
+static void cancel_callback (GtkWidget *widget, gint arg1, Simulation *s);
 static void input_done_callback (SimEngine *engine, Simulation *s);
 static void input_aborted_callback (SimEngine *engine, Simulation *s);
 static gboolean simulate_cmd (Simulation *s);
@@ -83,8 +82,9 @@ simulation_show (GtkWidget *widget, SchematicView *sv)
 	GladeXML *gui;
 	Simulation *s;
 	Schematic *sm;
-	gchar *msg;
-	gchar *fullpath = NULL;
+	gchar *title, *desc;
+	gchar *fullpath_parser = NULL;
+	gchar *fullpath_engine = NULL;
 
 	g_return_if_fail (sv != NULL);
 
@@ -99,38 +99,47 @@ simulation_show (GtkWidget *widget, SchematicView *sv)
 		return;
 	}
 
-	fullpath = g_find_program_in_path (oregano.simexec);
-	if (oregano.simexec && !fullpath) {
-		msg = g_strdup_printf (_("<span weight=\"bold\" size=\"x-large\">Could not find the simulation executable</span>\n\n"
-			"This probably means that you have not configured Oregano properly."));
-		oregano_error (msg);
-		g_free (msg);
+	fullpath_parser = g_find_program_in_path (oregano.simexec);
+	fullpath_engine = g_find_program_in_path (oregano.simtype);
+
+	if (oregano.simexec && (!fullpath_parser || !fullpath_engine)) {
+		title = g_strdup_printf (_("Could not find the simulation executable"));
+		desc  = g_strdup_printf (_("This probably means that you have not configured Oregano properly."));
+		oregano_error_with_title (title, desc);
+		g_free (title);
+		g_free (desc);
+		if (fullpath_parser != NULL) g_free (fullpath_parser);
+		if (fullpath_engine != NULL) g_free (fullpath_engine);
 		return;
 	} else if (!oregano.simexec) {
-		oregano_error (_("<span weight=\"bold\" size=\"x-large\">You have not entered a simulation executable.</span>\n\n"
-			"Please choose Settings and specify which"
-			"program to use for simulations."));
-		if (fullpath != NULL) g_free (fullpath);
+		title = g_strdup_printf (_("You have not entered a simulation executable"));
+		desc  = g_strdup_printf (_("Please choose Settings and specify which program to use for simulations."));
+		oregano_error_with_title (title, desc);
+		g_free (title);
+		g_free (desc);
+		if (fullpath_parser != NULL) g_free (fullpath_parser);
+		if (fullpath_engine != NULL) g_free (fullpath_engine);
 		return;
 	}
 
-	if (fullpath != NULL) g_free (fullpath);
+	if (fullpath_parser != NULL) g_free (fullpath_parser);
+	if (fullpath_engine != NULL) g_free (fullpath_engine);
 	if (!g_file_test (OREGANO_GLADEDIR "/simulation.glade2",
 		G_FILE_TEST_EXISTS)) {
-		oregano_error (_("Could not create simulation dialog."));
+		oregano_error (_("Could not create simulation dialog"));
 		return;
 	}
 
 	gui = glade_xml_new (OREGANO_GLADEDIR "/simulation.glade2", "toplevel", NULL);
 
 	if (!gui) {
-		oregano_error (_("<span weight=\"bold\" size=\"x-large\">Could not create simulation dialog.</span>"));
+		oregano_error (_("Could not create simulation dialog"));
 		return;
 	}
 
 	w = glade_xml_get_widget (gui, "toplevel");
 	if (!w) {
-		oregano_error (_("<span weight=\"bold\" size=\"x-large\">Could not create simulation dialog.</span>"));
+		oregano_error (_("Could not create simulation dialog"));
 		return;
 	}
 
@@ -143,15 +152,12 @@ simulation_show (GtkWidget *widget, SchematicView *sv)
 	w = glade_xml_get_widget (gui, "progressbar");
 	s->progress = GTK_PROGRESS_BAR (w);
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (s->progress), 0.0);
-//	gtk_widget_draw (w, NULL);	Aparently there is no need to do this, maybe gtk_widget_queue_draw_area ()
 
-/*		  gnome_dialog_button_connect (GNOME_DIALOG (s->dialog),
-		  0,
-		  cancel_callback,
-		  s);
+	g_signal_connect (G_OBJECT (s->dialog),
+		"response",
+		G_CALLBACK (cancel_callback),
+		s);
 
-		  gnome_dialog_set_parent (GNOME_DIALOG (s->dialog), GTK_WINDOW (sv->toplevel));
-*/
 	gtk_widget_show_all (GTK_WIDGET (s->dialog));
 
 	s->sv = sv;
@@ -220,7 +226,7 @@ input_aborted_callback (SimEngine *engine, Simulation *s)
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_YES_NO,
-			_("<span weight=\"bold\" size=\"x-large\">The simulation was aborted due to an error.</span>\n\n"
+			_("<span weight=\"bold\" size=\"large\">The simulation was aborted due to an error.</span>\n\n"
 				"Would you like to view the error log?"));
 
 
@@ -234,14 +240,14 @@ input_aborted_callback (SimEngine *engine, Simulation *s)
 			schematic_view_log_show (s->sv, TRUE);
 		}
 	} else {
-		oregano_error (_("<span weight=\"bold\" size=\"x-large\"> The simulation was aborted due to an error.</span>\n"));
+		oregano_error (_("The simulation was aborted due to an error"));
 
 		schematic_view_log_show (s->sv, FALSE);
 	}
 }
 
 static void
-cancel_callback (GtkWidget *widget, Simulation *s)
+cancel_callback (GtkWidget *widget, gint arg1, Simulation *s)
 {
 	g_return_if_fail (s != NULL);
 
